Class: PgObjects::Config
- Inherits:
-
Object
- Object
- PgObjects::Config
- Extended by:
- Dry::Configurable, YamlConfigurable
- Defined in:
- lib/pg_objects/config.rb
Constant Summary collapse
- DEFAULT_YAML_PATH =
'config/pg_objects.yml'
Class Method Summary collapse
-
.config ⇒ Object
YAML loading is deferred to the first config access so the path is resolved against Rails.root (when available) instead of the require-time working directory — preloaders like Spring may require the gem before the process chdirs into the app root.
Methods included from YamlConfigurable
Class Method Details
.config ⇒ Object
YAML loading is deferred to the first config access so the path is resolved against Rails.root (when available) instead of the require-time working directory — preloaders like Spring may require the gem before the process chdirs into the app root.
67 68 69 70 |
# File 'lib/pg_objects/config.rb', line 67 def config ensure_yaml_loaded super end |